NLSL: ftwork Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
ftwork Module Reference

## Variables
double precision, dimension(mxpt), save | work
double precision, dimension(mxpt), save | work2
double precision, dimension(mxpt), save | tmpclc
double precision, dimension(mxpt), save | tmpdat

## Variable Documentation

double precision, dimension (mxpt), save ftwork::tmpclc

Definition at line 26 of file ftwork.f90.

double precision, dimension (mxpt), save ftwork::tmpdat

Definition at line 26 of file ftwork.f90.

double precision, dimension (mxpt), save ftwork::work

Definition at line 26 of file ftwork.f90.

double precision, dimension (mxpt), save ftwork::work2

Definition at line 26 of file ftwork.f90.